(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     75649,       2278]*)
(*NotebookOutlinePosition[    121498,       3849]*)
(*  CellTagsIndexPosition[    119858,       3812]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Kapitel 2"]], "Subtitle"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Methoden"]], "Title",
  CounterAssignments->{{"Title", 1}}],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox[". Motivation"]
}], "Section"],

Cell[TextData[{
  StyleBox[
  "Eigentlich ist zu den L\[ODoubleDot]sungsmethoden linearer Gleichungen \
schon genug geschrieben worden (z. B. "],
  ButtonBox["[Metz1996]",
    ButtonData:>{"Literatur.nb", "[Metz1996]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ", Abschnitt 3.5, S. 23-26). In diesem Kapitel wird trotzdem die Verwendung \
von Fourier- und Laplace-Technik zur Erzeugung von Propagatoren und \
Greenschen Funktionen kurz angedeutet und erweitert."]
}], "Text"],

Cell[TextData[{
  "Der Hauptgrund f\[UDoubleDot]r dieses Kapitel ist die Verdeutlichung der \
Verwendbarkeit der Diracschen ",
  StyleBox["Delta-Funktion",
    FontSlant->"Italic"],
  " als funktionentheoretisch konsistente analytische Funktion. Au\[SZ]erdem \
soll gezeigt werden, wie mit ihrer Hilfe auch kompliziertere lineare \
Differentialgleichungen (auch fraktionale) eventuell gel\[ODoubleDot]st \
werden k\[ODoubleDot]nnen, besonders im Hinblick auf die Momentenberechnung."
}], "Text"],

Cell[TextData[{
  "Die hier vorgestellten Ergebnisse bilden eine wesentliche theoretische \
Erweiterung, ohne die ein konsistentes Zustandekommen des Programmpakets ",
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  " nicht m\[ODoubleDot]glich gewesen w\[ADoubleDot]re. In der nun folgenden \
Abhandlung sind die Grundlagen so dargestellt, da\[SZ] ein \
Verst\[ADoubleDot]ndnis des Programmpakets zwar hilfreich, aber nicht \
notwendig ist, um inhaltlich folgen zu k\[ODoubleDot]nnen."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Die Diracsche Delta-Funktion"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Singul\[ADoubleDot]re Integrale"
}], "Subsection"],

Cell["\<\
Wenn ein bestimmtes Integral bei einer gewissen Parameterwahl \
divergiert, so hat es durchaus Sinn, die L\[ODoubleDot]sungsgesamtheit in \
einer m\[ODoubleDot]glichst geschlossenen Form darzustellen.\
\>", "Text"],

Cell["\<\
Zur Darstellung dieser eventuell singul\[ADoubleDot]ren \
Integralergebnisse eignet sich unter anderem auch die Diracsche \
Delta-Funktion. Ihr wird trotzdem heute noch von manchen Mathematikern mit Mi\
\[SZ]trauen begegnet, da der \[CapitalUDoubleDot]bergang in die Singularit\
\[ADoubleDot]t unstetig erfolgt.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox[". Die Fourier-Transformation der Eins"]
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Eigenschaften der Fourier-Transformation"]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox[
  "Die Fourier-Transformation einer Konstante l\[ADoubleDot]\[SZ]t sich auf \
diejenige der Eins zur\[UDoubleDot]ckf\[UDoubleDot]hren. Das Fourier-Integral \
selbst lautet im Zusammenhang dieser Arbeit und bei der "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[
  "-Version 3.0 (Es gibt auch Abweichungen davon in anderen Arbeiten \
hinsichtlich des Vorfaktors und Vorzeichens, zum Beispiel bei "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[" 4.0):"]
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalF]\_x\%k[f[x]] := 
      \[Integral]\_\(-\[Infinity]\)\%\[Infinity] Exp[
            \(+\[ImaginaryI]\)\ k\ x] f[x] \(\[DifferentialD]x . \)\)], 
  "NumberedEquation",
  CellTags->"Fourier-Transformation"],

Cell[TextData[{
  StyleBox["F\[UDoubleDot]r symmetrische Funktionen mit "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f[\(-x\)] = f[x]\)]]],
  StyleBox[
  " kann die Fourier-Transformation in die Cosinus-Transformation \
\[UDoubleDot]berf\[UDoubleDot]hrt werden:"]
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalF]\&c\_x\%k[f[x]] := 
      \[Integral]\_0\%\[Infinity] Cos[k\ x] f[x] \(\[DifferentialD]x . \)\)], 
  "NumberedEquation",
  CellTags->"Cosinus-Transformation"],

Cell[TextData[StyleBox[
"Weitere Eigenschaften der Fourier-Transformationen sind im Anhang B dieser \
Arbeit aufgelistet."]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Verwendung des Mittelwertsatzes"]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox[
  "Die Fourier-Transformation der Eins f\[UDoubleDot]hrt von Gleichung ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Fourier-Transformation"]],
  StyleBox[") auf das Doppelte von Gleichung ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Cosinus-Transformation"]],
  StyleBox[
  "), wobei nun ein parametrisiertes Integral zu l\[ODoubleDot]sen ist:"]
}], "Text"],

Cell[BoxData[
    RowBox[{\(\[ScriptCapitalF]\_x\%k[1]\), "=", 
      RowBox[{\(2  \[ScriptCapitalF]\&c\_x\%k[1]\), "=", 
        RowBox[{
        \(2 \(\[Integral]\_0\%\[Infinity] Cos[k\ x] \[DifferentialD]x\)\), 
          "=", 
          RowBox[{"{", GridBox[{
                {\(\[Infinity]\ \ \ \ \ \ \ \ \ \ \ \ \ \ k = 0, \)},
                {\(\ 0\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ k \[NotEqual] 0. \)}
                }]}]}]}]}]], "NumberedEquation",
  CellTags->"Fourier-Transformation der Eins"],

Cell[TextData[{
  StyleBox[
  "Die errechneten Ergebnisse sind \[UDoubleDot]ber den Mittelwertsatz ("],
  ButtonBox["[Rot1954]",
    ButtonData:>{"Literatur.nb", "[Rot1954]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[", II. \[Section]13.9, S. 86-87) gut zu verstehen, da bei "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`k \[NotEqual] 0\)]]],
  StyleBox[
  " eine Mittelung \[UDoubleDot]ber unendlich viele Perioden der \
Cosinus-Funktion stattfindet. Das Integral \[UDoubleDot]ber endlich viele \
Cosinus-Perioden ergibt ohnehin Null."]
}], "Text"],

Cell[TextData[{
  StyleBox["Andere Zug\[ADoubleDot]nge zum Integral ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", 
  "Fourier-Transformation der Eins"]],
  StyleBox[
  ") ergeben unbestimmte Terme. Die Formulierung eines eindeutigen \
Ergebnisses ist zwar m\[ODoubleDot]glich, aber nicht durchgehend akzeptiert."]
    
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Definition der Delta-Funktion nach Dirac"]
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  StyleBox[
  "P. A. M. Dirac gibt nun eine Funktion an, die die Eigenschaften von \
Gleichung ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", 
  "Fourier-Transformation der Eins"]],
  StyleBox[
  ") besitzt und bei inverser Fourier-Transformation die Eins \
zur\[UDoubleDot]ckliefern kann. Diese Delta-Funktion ist \[UDoubleDot]ber \
folgende drei Annahmen definiert ("],
  ButtonBox["[Dir1927]",
    ButtonData:>{"Literatur.nb", "[Dir1927]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[", S. 625-626):"]
}], "Text"],

Cell[BoxData[
    \(\(\[Delta][x] = 0\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ x \[NotEqual] 0, \)\)],
   "NumberedEquation",
  CellTags->"1.Delta-Axiom"],

Cell[BoxData[
    \(\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\[DifferentialD]x\ 
          \[Delta][x] = 1, \)\)], "NumberedEquation",
  CellTags->"2.Delta-Axiom"],

Cell[BoxData[
    \(\[Delta][x] = \(\[Delta][ | x | ] . \)\)], "NumberedEquation",
  CellTags->"3.Delta-Axiom"],

Cell[TextData[{
  StyleBox[
  "In der Originalarbeit von Dirac befindet sich ein Druckfehler bei der \
Formulierung von Definition ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "2.Delta-Axiom"]],
  StyleBox[
  "), was die Kritisierbarkeit seiner Arbeit leider verst\[ADoubleDot]rkt."]
}], "Text"],

Cell[TextData[{
  "Eine funktionentheoretisch konsistente Konsequenz aus den Definitionen (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "1.Delta-Axiom"],
  ") bis (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "3.Delta-Axiom"],
  ") ergibt eine komplexe Phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi]\)]],
  " des Integrals in Abh\[ADoubleDot]ngigkeit von der Richtung des \
Integrationswegs, die hier gleich in einer m\[ODoubleDot]glichst allgemein \
verwertbaren Darstellung erfolgt:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\(Exp[\[ImaginaryI]\ \[CurlyPhi]]\)\[Delta][x] 
          \[DifferentialD]x = 
      \(\((Exp[\[ImaginaryI]\ \[CurlyPhi]]\/2)\).\)\)], "NumberedEquation",
  CellTags->"Praktisches Delta-Integral"],

Cell[TextData[{
  "Es sei darauf hingewiesen, da\[SZ] bereits Dirac in seiner Arbeit die \
Delta-Funktion mit komplexen Argumenten diskutiert (",
  ButtonBox["[Dir1927]",
    ButtonData:>{"Literatur.nb", "[Dir1927]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (1), S. 626); dieses Ergebnis ist immer noch fundamental:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[x] \[Delta][a - x] 
          \[DifferentialD]x = \(f[a] . \)\)], "NumberedEquation",
  CellTags->"Delta-Theorem"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Bestimmung des Vorfaktors der Fourier-Transformation"
}], "Subsubsection"],

Cell[TextData[{
  StyleBox[
  "Da die Delta-Funktion in der L\[ODoubleDot]sungstheorie linearer \
Gleichungen eine gro\[SZ]e Rolle spielt, besteht eine sinnvolle Konvention \
der Mathematik darin, die Fourier-Transformation der Delta-Funktion auf Eins \
zu setzen. Mit der oben angef\[UDoubleDot]hrten Definition der \
Fourier-Transformation ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Fourier-Transformation"]],
  StyleBox[") ergibt sich zusammen mit Gleichung ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Delta-Theorem"]],
  StyleBox[") folgendes Ergebnis:"]
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalF]\_x\%k[\[Delta][x]] = 
      \(2  \[ScriptCapitalF]\&c\_x\%k[\[Delta][x]] = 
        \(2 \(\[Integral]\_0\%\[Infinity] Cos[k\ x] \[Delta][x] 
                \[DifferentialD]x\) = 1. \)\)\)], "NumberedEquation",
  CellTags->"Fourier-Transformation der Delta-Funktion"],

Cell[TextData[{
  "Die Fourier-Transformation der Eins ist also proportional zur Diracschen \
Delta-Funktion. Die Proportionalit\[ADoubleDot]tskonstante ergibt sich aus \
der inversen Fourier-Transformation unter Ausnutzung der Selbstinversit\
\[ADoubleDot]t der Cosinus-Transformation mit Hilfe von Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  "):"
}], "Text",
  PageBreakAbove->True],

Cell[BoxData[
    \(\((\[ScriptCapitalF]\^\(-1\))\)\_k\%x[2  \[Pi]\ \[Delta][k]] = 
      \(\(1\/\[Pi]\) \[ScriptCapitalF]\&c\_k\%x[2\ \[Pi]\ \[Delta][k]] = 
        \(\(\(2  \[Pi]\)\/\[Pi]\) 
            \(\[Integral]\_0\%\[Infinity] Cos[k\ x] \[Delta][k] 
                \[DifferentialD]k\) = 1. \)\)\)], "NumberedEquation",
  CellTags->"Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"],

Cell[TextData[{
  StyleBox[
  "Die Delta-Funktion schafft also Klarheit, wenn es darum geht, die \
Vorfaktoren der Fourier-Transformationen gem\[ADoubleDot]\[SZ] der Definition \
("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Fourier-Transformation"]],
  StyleBox[
  ") festzulegen. Diese Klarheit ist sp\[ADoubleDot]testens bei Einsatz von \
Computeralgebra notwendig."]
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox[". Die Mellin-Transformation der Eins"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Ergebnis aus der Fourier-Transformation"]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox[
  "Bereits Mellin weist auf eine enge Verwandtschaft von Fourier- und \
Mellin-Transformation hin ("],
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ", \[Section]8, S. 324). Eine explizite Durchf\[UDoubleDot]hrung der \
entsprechenden Transformationen ergibt sich mit Hilfe der Substitutionen "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \(-Log[x]\)\)]]],
  StyleBox[" und "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Zeta] \[Rule] \[ImaginaryI]\ z\)]]],
  StyleBox[":"]
}], "Text"],

Cell[BoxData[
    \(f[x] = 
      \(f[\[ExponentialE]\^\(-t\)] = 
        \(\(1\/\(2  \[Pi]\)\) 
            \(\[Integral]\_\(-
                  \[Infinity]\)\%\[Infinity]\( 
                    \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Zeta]\ t\)\) 
                \[DifferentialD]\[Zeta] 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[
                      \[ExponentialE]\^\(-t\)]\ 
                    \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Zeta]\ t\)\) 
                    \[DifferentialD]t\)\) = \n\t\t\t\n
          \(\( = \(\(-\[ImaginaryI]\)\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \[Integral]\_\(-
                    \[Infinity]\)\%\[Infinity]\( x
                      \^\(\[ImaginaryI]\ \[Zeta]\)\) \[DifferentialD]\[Zeta] 
                  \(\[Integral]\_0\%\[Infinity] f[x]\ 
                      \(x\^\(\(-\[ImaginaryI]\)\ \[Zeta] - 1\)\) 
                      \[DifferentialD]x\)\) = \n\t\t\t\t\t\n
            \( = \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \[Integral]\_\(\(-\[ImaginaryI]\)\ 
                    \[Infinity]\)\%\(\[ImaginaryI]\ 
                    \[Infinity]\)\(x\^\(-z\)\) \[DifferentialD]z 
                  \(\[Integral]\_0\%\[Infinity] f[x]\ \(x\^\(z - 1\)\) 
                      \(\[DifferentialD]x . \)\)\)\)\)\)\)], 
  "NumberedEquation",
  CellTags->"Fourier-Mellin-Transformationen"],

Cell[TextData[{
  StyleBox["Die Zwischenergebnisse dieser Transformationen ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", 
  "Fourier-Mellin-Transformationen"]],
  StyleBox[") ergeben mit dem Residuum ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", 
  "Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"]],
  StyleBox[") und der Definition ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "3.Delta-Axiom"]],
  StyleBox[
  ") die Mellin-Transformation der Eins, bei deren Berechnung der Verfasser \
durch Herrn Professor Dr. W. Wonneberger (Ulm) freundlicherweise unterst\
\[UDoubleDot]tzt wurde:"]
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\( x\^\(z - 1\)\) \[DifferentialD]x = 
      \(2  \[Pi]\ \[Delta][\[Zeta]] = 
        \(2  \[Pi]\ \[Delta][\[ImaginaryI]\ z] = 
          2  \[Pi]\ \(\[Delta][z] . \)\)\)\)], "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Mellin-Residuum der Delta-Funktion"]
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  StyleBox["Die inverse Mellin-Transformation des Resultats ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Mellin-Transformation der Eins"]],
  StyleBox[") ergibt mit dem Integral ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Praktisches Delta-Integral"]],
  StyleBox[") gem\[ADoubleDot]\[SZ] den Gleichungen ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", 
  "Fourier-Mellin-Transformationen"]],
  StyleBox["):"]
}], "Text"],

Cell[BoxData[
    \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(\(-\[ImaginaryI]\)\ \[Infinity]\)\%\(\[ImaginaryI]\ 
              \[Infinity]\)\[Delta][z]\ \(x\^\(-z\)\) \[DifferentialD]z\) = 
      \(\((1\/\(2\ \[Pi]\))\).\)\)], "NumberedEquation",
  CellTags->"Mellin-Residuum der Delta-Funktion"],

Cell[TextData[{
  StyleBox[
  "Im Sinne der Mellin-Transformation ist somit sogar das Residuum der \
Delta-Funktion trotz Richtungsabh\[ADoubleDot]ngigkeit des Integrals ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Praktisches Delta-Integral"]],
  StyleBox[") eindeutig. Eine Berechnung dieses "],
  StyleBox["Mellin-Residuums",
    FontSlant->"Italic"],
  StyleBox[
  " \[UDoubleDot]ber die sonst f\[UDoubleDot]r stetig erreichbare Singularit\
\[ADoubleDot]ten geltenden Formeln kann mi\[SZ]lingen."]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Unabh\[ADoubleDot]ngige Best\[ADoubleDot]tigung"]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox[
  "Um keine Inkonsistenzen zu etablieren, ist es sehr lohnend, ein neues \
Ergebnis auf verschiedene Arten herzuleiten. Deshalb soll die \
Mellin-Transformation der Eins ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Mellin-Transformation der Eins"]],
  StyleBox[
  ") nun auf unabh\[ADoubleDot]ngigem Wege best\[ADoubleDot]tigt werden. Das \
Integral selbst gilt als divergent f\[UDoubleDot]r alle reellen "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`z\)]]],
  StyleBox["."]
}], "Text"],

Cell[TextData[{
  StyleBox["F\[UDoubleDot]r "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`z \[NotEqual] 1\)]]],
  StyleBox[
  " ergibt die Mellin-Transformation der Eins in den Integrationsintervallen \
"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] x \[LessEqual] 1\)]]],
  StyleBox[" und "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] x \[LessEqual] \[Infinity]\)]]],
  StyleBox[
  " folgende beiden Funktionen, die ihrerseits analytisch fortsetzbar sind:"]
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\( x\^\(z - 1\)\) \[DifferentialD]x = 
      \(\[Integral]\_0\%1\( x\^\(z - 1\)\) \[DifferentialD]x + 
          \[Integral]\_1\%\[Infinity]\( x\^\(z - 1\)\) \[DifferentialD]x = 
        1\/z - 1\/z\), \n\nRe[z] > 0\ \ und\ \ Re[z] < 0. \)], 
  "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins explizit 1.Teil"],

Cell[TextData[{
  StyleBox["Das Wort \""],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`und\)]]],
  StyleBox["\" im Ergebnis ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", 
  "Mellin-Transformation der Eins explizit 1.Teil"]],
  StyleBox[
  ") verwirrt immer wieder, da es zwar den naheliegenden Trugschlu\[SZ] n\
\[ADoubleDot]hrt, der Realteil von "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`z\)]]],
  StyleBox[" m\[UDoubleDot]sse "],
  StyleBox["gleichzeitig",
    FontSlant->"Italic"],
  StyleBox[
  " positiv und negativ sein, aber trotzdem gen\[UDoubleDot]gend deutlich \
macht, da\[SZ] zun\[ADoubleDot]chst einmal zwei verschiedene \
G\[UDoubleDot]ltigkeitsbereiche "],
  StyleBox["gleichzeitig",
    FontSlant->"Italic"],
  StyleBox[
  " auseinandergehalten werden m\[UDoubleDot]ssen, bevor die jeweilige \
analytische Fortsetzung der Teilergebnisse erfolgt. Das angegebene Integral \
bereitete dem Verfasser bereits im Rahmen seiner Diplomarbeit Schwierigkeiten \
("],
  ButtonBox["[S\[UDoubleDot]d1997]",
    ButtonData:>{"Literatur.nb", "[Sued1997]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ", Abschnitte 3.1.4.3 und 6.3.3, S. 42-44 und 93-94), die aber nun sogar f\
\[UDoubleDot]r die Computeralgebra gel\[ODoubleDot]st sind."]
}], "Text"],

Cell[TextData[{
  StyleBox["F\[UDoubleDot]r "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`z = 0\)]]],
  StyleBox[
  " ergibt die Mellin-Transformation der Eins logarithmische Singularit\
\[ADoubleDot]ten, die nicht \[UDoubleDot]ber eine analytische Fortsetzung von \
konvergenten Teilintegralen zu beseitigen sind:"]
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\[DifferentialD]x\/x = 
      Log[x] |\_0\%\[Infinity]\(\( = \[Infinity] + \[Infinity]\) = 
          \(\[Infinity] . \)\)\)], "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins explizit 2.Teil"],

Cell[TextData[{
  StyleBox[
  "Da die Mellin-Transformation nach der etablierten Funktionen- und \
Integraltheorie stets G\[UDoubleDot]ltigkeitsbereiche f\[UDoubleDot]r \
polfreie Resultate liefert, ist immer eine analytische Fortsetzung im \
Mellin-Raum in die Polstellen des Ergebnisses hinein erforderlich, damit die \
inverse Mellin-Transformation \[UDoubleDot]ber den Residuensatz mit Hilfe \
dieser Polstellen erfolgen kann (vgl. "],
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[", G\[UDoubleDot]ltigkeitsbereiche von Gl. (40), S. 316)."]
}], "Text",
  PageBreakAbove->True],

Cell[TextData[StyleBox[
"Bei der Implementation der Mellin-Transformation f\[UDoubleDot]r die \
Computeralgebra fiel dem Verfasser diese Eigenschaft der \
Mellin-Transformation sehr schnell auf, da die Polstellen f\[UDoubleDot]r die \
Residuenberechnung immer au\[SZ]erhalb des errechneten \
G\[UDoubleDot]ltigkeitsbereichs der Mellin-Transformierten lagen."]], "Text"],

Cell[TextData[{
  StyleBox["Als Merkregel ergibt sich generell, da\[SZ] die "],
  StyleBox["G\[UDoubleDot]ltigkeitsbereiche im Mellin-Raum",
    FontSlant->"Italic"],
  StyleBox[
  " f\[UDoubleDot]r die Integralkonvergenz des Mellin-Integrals zwar stimmen, \
aber ansonsten "],
  StyleBox["ignoriert werden m\[UDoubleDot]ssen",
    FontSlant->"Italic"],
  StyleBox[
  "! Es mag sein, da\[SZ] gerade diese Eigenschaft der Mellin-Transformation \
so manchen Mathematiker davon abh\[ADoubleDot]lt, sich n\[ADoubleDot]her mit \
den M\[ODoubleDot]glichkeiten dieser Transformation auseinanderzusetzen."]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Konsequenzen aus dem Satz von Mellin"]
}], "Subsubsection"],

Cell[TextData[{
  "Der Satz von Mellin benennt ein Paar aus Funktion und \
Mellin-Transformierter als reziproke Funktionen und besagt (",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", S. 323):"
}], "Text"],

Cell[TextData[StyleBox[
"\"Von zwei reziproken Funktionen kann die eine nur dann identisch\n \
verschwinden, wenn auch die andere identisch gleich Null ist.\""]], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[TextData[{
  StyleBox[
  "In der Anwendung auf die soeben erfolgreich unter Verwendung aller \
Rechenregeln erhaltenen Ergebnisse ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Mellin-Transformation der Eins"]],
  StyleBox[") und ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", 
  "Mellin-Residuum der Delta-Funktion"]],
  StyleBox[") ist der Satz von Mellin der "],
  StyleBox["Existenzbeweis der Diracschen Delta-Funktion",
    FontSlant->"Italic"],
  StyleBox["."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "Der Verfasser h\[ADoubleDot]lt den Satz von Mellin f\[UDoubleDot]r einen \
der schwerverst\[ADoubleDot]ndlichsten und unbekanntesten S\[ADoubleDot]tze \
der analytischen Mathematik. Zu seinem Verst\[ADoubleDot]ndnis \
w\[ADoubleDot]re eine Zusatzvorlesung "],
  StyleBox["Funktionentheorie III",
    FontSlant->"Italic"],
  StyleBox[" notwendig."]
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox[". Die Momente der Delta-Funktion"]
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Zusammenhang zwischen Mellin-Transformation und Momenten"]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Die Momentenintegrale der Ordnung "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`m\)]]],
  StyleBox[" einer Verteilungsfunktion "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f[x]\)]]],
  StyleBox[" sind folgenderma\[SZ]en definiert ("],
  ButtonBox["[BrS1987]",
    ButtonData:>{"Literatur.nb", "[BrS1987]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[", Abschnitt 5.1.3, S. 667 oben):"]
}], "Text"],

Cell[BoxData[
    \(\(x\^m\)\&_ = \(\(\( < x\)\^m > \)\  = \ \( < x\)\^m\), 
    \(f[x] > \)\  := 
      \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( x\^m\) f[x] 
          \(\[DifferentialD]x . \)\)], "NumberedEquation",
  CellTags->"Momente"],

Cell[TextData[{
  StyleBox[
  "Die Mellin-Transformation ist \[UDoubleDot]ber folgendes Integral ("],
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[", \[Section]8, Gl. (51), S. 319) gegeben:"]
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalM]\_x\%z[f[x]] := 
      \[Integral]\_0\%\[Infinity]\( x\^\(z - 1\)\) f[x] 
          \(\[DifferentialD]x . \)\)], "NumberedEquation",
  CellTags->"Mellin-Transformation"],

Cell[TextData[{
  StyleBox["Symmetrische Momente werden mit den Betr\[ADoubleDot]gen "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\( \[VerticalBar] x\( \[VerticalBar] \^m\)\)\)]]],
  StyleBox[" statt mit "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\^m\)]]],
  StyleBox[
  " berechnet, wobei die Integrationsgrenzen eine symmetrische \
Verteilungsfunktion "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f[x] = f[ \[VerticalBar] x \[VerticalBar] ]\)]]],
  StyleBox[
  " voraussetzen. Es ergibt sich folgender Zusammenhang zwischen den \
symmetrischen Momenten "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm
      \`\( <  \[VerticalBar] x\( \[VerticalBar] \^m\) > \)\)]]],
  StyleBox[" und der Mellin-Transformation einer Funktion:"]
}], "Text"],

Cell[BoxData[
    \(\( <  \[VerticalBar] x\( \[VerticalBar] \^m\) > \)\  = \ 
      \( <  \[VerticalBar] x\( \[VerticalBar] \^m\)\), 
    \(f[ \[VerticalBar] x \[VerticalBar] ] > \)\  = \n\t\n
      \(\( = 2  \[ScriptCapitalM]\_x\%\(m + 1\)[f[x]]\) = 
        2 \(\[Integral]\_0\%\[Infinity]\( x\^\(m + 1 - 1\)\) f[x] 
              \(\[DifferentialD]x . \)\)\)\)], "NumberedEquation",
  CellTags->"Symmetrische Momente"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["Section"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsection"]],
  StyleBox["."],
  StyleBox[CounterBox["Subsubsection"]],
  StyleBox[". Berechnung der Delta-Momente"]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox[
  "Die symmetrischen Momente der Delta-Funktion ergeben mit den Gleichungen \
("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Symmetrische Momente"]],
  StyleBox["), ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Praktisches Delta-Integral"]],
  StyleBox[") und ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "3.Delta-Axiom"]],
  StyleBox["):"]
}], "Text"],

Cell[BoxData[
    RowBox[{\( <  \[VerticalBar] x\( \[VerticalBar] \^m\)\), ",", 
      RowBox[{\(\[Delta][x] > \), " ", "=", 
        RowBox[{"{", GridBox[{
              {\(1\ \ \ \ \ \ \ \ \ \ \ m = 0, \)},
              {\(0\ \ \ \ \ \ \ \ \ \ \ m > 0. \)}
              }]}]}]}]], "NumberedEquation",
  CellTags->"Delta-Momente"],

Cell[TextData[{
  StyleBox["Allgemeiner formuliert ergibt die Mellin-Transformation ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Mellin-Transformation"]],
  StyleBox[") der Delta-Funktion gem\[ADoubleDot]\[SZ] Beziehung ("],
  StyleBox[CounterBox["Title"]],
  StyleBox["."],
  StyleBox[CounterBox["NumberedEquation", "Praktisches Delta-Integral"]],
  StyleBox[") eine recht eigenartige Funktion:"]
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalM]\_x\%z[\[Delta][x]] = \(\((0\^\(z - 1\)\/2)\).\)\)], 
  "NumberedEquation",
  CellTags->"Null hoch z"],

Cell[TextData[{
  "Die Funktion (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Null hoch z"],
  ") ist deshalb sehr eigenartig, weil die inverse Mellin-Transformation von \
",
  Cell[BoxData[
      \(TraditionalForm\`0\^z\)]],
  " wieder auf die singul\[ADoubleDot]re Delta-Funktion zur\[UDoubleDot]ckf\
\[UDoubleDot]hrt."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". M\[ODoubleDot]glichkeiten zur Erweiterung der Funktionentheorie"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Angesichts von Resultaten wie (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Null hoch z"],
  ") kommt auch ein erfahrener Mathematiker an seine Grenzen. Das formale \
Weiterrechnen mit den formal erhaltenen Formeln ergibt stets sinnvolle \
Ergebnisse, wobei selbst ein Computer keine Inkonsistenzen dieser M\
\[ODoubleDot]glichkeit findet."
}], "Text"],

Cell[TextData[{
  "Die Resultate (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Momente"],
  ") und (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Null hoch z"],
  ") legen mit (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Symmetrische Momente"],
  ") den Schlu\[SZ] nahe, den Funktionswert von ",
  Cell[BoxData[
      \(TraditionalForm\`0\^z\)]],
  " f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " unstetig auf Eins zu definieren. Ein direkter Zugang \[UDoubleDot]ber \
Grenzwerte der Art ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] 0\)]],
  " ist dann freilich nicht m\[ODoubleDot]glich, wohl aber eine Motivation \
\[UDoubleDot]ber eine Analogie zur Hausdorff-Dimension (",
  ButtonBox["[Non1996]",
    ButtonData:>{"Literatur.nb", "[Non1996]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (2.4), S. 37) parametrisierter Grenzwerte:"
}], "Text"],

Cell[BoxData[
    \(0\^z := \(\ lim\)\+\(\[Delta]\  \[Rule] \ 0\)\ \(\[Delta]\^z.\)\)], 
  "NumberedEquation",
  CellTags->"genaueres Null hoch z"],

Cell[TextData[{
  "Das Eigenartige an der ",
  Cell[BoxData[
      \(TraditionalForm\`0\^z\)]],
  "-Funktion ist, da\[SZ] der Betrag der Funktion f\[UDoubleDot]r alle ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " eindeutig ist, w\[ADoubleDot]hrend die komplexe Phase vor allem f\
\[UDoubleDot]r rein imagin\[ADoubleDot]re ",
  Cell[BoxData[
      \(TraditionalForm\`z \[NotEqual] 0\)]],
  " viele \[CapitalUDoubleDot]berraschungen bereith\[ADoubleDot]lt."
}], "Text"],

Cell[TextData[{
  "Bei der Absch\[ADoubleDot]tzung von Integralkonvergenz wird bei \
Ergebnistermen der Form ",
  Cell[BoxData[
      \(TraditionalForm\`x\^z\)]],
  " deshalb f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`Re[x] > 0\)]],
  " und eventuell noch f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`Re[z] > 0\)]],
  " eine Aussage gemacht. Bereits der Fall ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " erzeugt Auseinandersetzungen, die im jeweils diskutierten Kontext des \
Resultats noch beendet werden k\[ODoubleDot]nnen."
}], "Text"],

Cell[TextData[{
  "Die Verwendung der Definition (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "genaueres Null hoch z"],
  ") als analytische Funktion in ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " scheint etwa so un\[UDoubleDot]blich zu sein wie die Diskussion von ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)]],
  " vor f\[UDoubleDot]nfhundert Jahren. Es mag das Anliegen \
sp\[ADoubleDot]terer Arbeiten sein, die ungekl\[ADoubleDot]rten Fragen dieser \
Art aufzuarbeiten. Die analytische Relevanz der ",
  Cell[BoxData[
      \(TraditionalForm\`0\^z\)]],
  "-Funktion ist immerhin durch die Momente der Delta-Funktion (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Momente"],
  ") aufgezeigt."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Laplace- und Fourier-Transformation"
}], "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Bekannte Zusammenh\[ADoubleDot]nge"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Vorgehensweise"
}], "Subsubsection"],

Cell[TextData[{
  "Bei der Laplace-Transformation (",
  ButtonBox["[BrS1987]",
    ButtonData:>{"Literatur.nb", "[BrS1987]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 4.4.3.1, S. 634) fraktionaler Diffusionsgleichungen sind der \
Differentiationssatz und der Faltungssatz ausreichend, um die integrierte \
Form der zeit-fraktionalen Differentialgleichung (1.26) in eine gew\
\[ODoubleDot]hnliche Differentialgleichung in der Ortskoordinate ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " umzuwandeln."
}], "Text"],

Cell[TextData[{
  "Die Integrationskonstanten, die bei Oldham/Spanier (",
  ButtonBox["[OS1974]",
    ButtonData:>{"Literatur.nb", "[OS1974]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 8.1, S. 133-136) im Zusammenhang mit fraktionalen Ableitungen \
angegeben werden, besitzen keinerlei physikalische Relevanz, wie die \
Diskussion der fraktionalen Anfangswertprobleme (Quellen siehe Kapitel 1.3.2 \
dieser Arbeit) ergibt. Sie k\[ODoubleDot]nnen beim Programmpaket ",
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  " wahlweise \[UDoubleDot]ber die Option ",
  StyleBox["OldhamSpanierConstants \[Rule] True",
    FontSlant->"Italic"],
  " zugeschaltet werden, wenn die Laplace-Transformation \
ausgef\[UDoubleDot]hrt wird."
}], "Text"],

Cell[TextData[{
  "Die anschlie\[SZ]ende Fourier-Transformation dieser \
gew\[ODoubleDot]hnlichen Differentialgleichung gelingt, wenn alle \
Anfangswertprobleme zun\[ADoubleDot]chst einmal auf die Diracsche \
Delta-Funktion gesetzt werden. Es ergibt sich im einfachsten Fall (auch bei \
fraktionalen Diffusionsgleichungen!) eine algebraische Gleichung, deren \
inverse Fourier- und inverse Laplace-Transformation auf ein eindeutiges \
Fundamentalsystem aus Propagatoren f\[UDoubleDot]hrt, das im Rahmen dieser \
Arbeit als das ",
  StyleBox["optimierte Fundamentalsystem",
    FontSlant->"Italic"],
  " bezeichnet wird."
}], "Text"],

Cell["\<\
Die Gesamtl\[ODoubleDot]sung ergibt sich, indem jeweils eine \
Fourier-Faltung mit den Anfangswertproblemen und den entsprechenden \
Fundamental-Propagatoren durchgef\[UDoubleDot]hrt wird.\
\>", "Text"],

Cell[TextData[{
  "Andere L\[ODoubleDot]sungstechniken linearer Differentialgleichungen f\
\[UDoubleDot]hren zum Beispiel auf eine ",
  StyleBox["Frobeniussche Normalform",
    FontSlant->"Italic"],
  " (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (11c), S. 188) eines Fundamentalsystems."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Begriff Propagator"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Ein Propagator ist Bestandteil des optimierten Fundamentalsystems einer \
partiellen linearen Differentialgleichung. Das zugeh\[ODoubleDot]rige \
Anfangswertproblem ist stets die Diracsche Delta-Funktion zur Zeit ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Bei der hier besprochenen L\[ODoubleDot]sungsstrategie ist die \
Zeitkoordinate anders zu behandeln als die Raumkoordinaten, da das \
Anfangswertproblem die r\[ADoubleDot]umliche Verteilung ",
  Cell[BoxData[
      \(TraditionalForm\`f[x, t \[Rule] 0]\)]],
  " beschreibt und nicht \[LongDash] was auch mathematisch \
m\[ODoubleDot]glich w\[ADoubleDot]re \[LongDash] die zeitliche Entwicklung \
der Dynamik an einem ganz bestimmten Ort ",
  Cell[BoxData[
      \(TraditionalForm\`f[x \[Rule] 0, t]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Die Fourier-Transformation einer Differentialgleichung kann \
\[UDoubleDot]ber die partielle Integration verstanden werden, wenn die \
sogenannten ",
  StyleBox["nat\[UDoubleDot]rlichen Randbedingungen",
    FontSlant->"Italic"],
  ", n\[ADoubleDot]mlich das Verschwinden der Funktion und ihrer Ableitungen \
im Unendlichen, erf\[UDoubleDot]llt sind. Bei Propagatoren ist diese \
Forderung wegen des Starts bei ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " als Delta-Funktion als erf\[UDoubleDot]llt anzusehen."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Begriff Greensche Funktion"
}], "Subsubsection"],

Cell[TextData[{
  "Im Gegensatz zu einem Propagator beschreibt eine Greensche Funktion die \
standardisierte L\[ODoubleDot]sung einer inhomogenen Differentialgleichung. \
Nach Hort/Thoma (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]107-108, S. 178-182) ist hierbei stets eine Integration mehr \
auszuf\[UDoubleDot]hren als bei homogenen Gleichungen."
}], "Text"],

Cell[TextData[{
  "Um die Grundfunktion zu ermitteln, die zu einer Integration mit der \
allgemeinen Inhomogenit\[ADoubleDot]t oder Steuergr\[ODoubleDot]\[SZ]e ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, t]\)]],
  " verwendet wird, wird wieder die Diracsche Delta-Funktion, diesmal zeitabh\
\[ADoubleDot]ngig, verwendet."
}], "Text"],

Cell["\<\
Die ermittelte Greensche Funktion wird im einfachsten Fall einer \
zeitlichen Laplace-Faltung und einer r\[ADoubleDot]umlichen Fourier-Faltung \
unterzogen, um die allgemeine inhomogene L\[ODoubleDot]sung der \
Ausgangsgleichung zu erhalten.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Erweiterungen"
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Laplace-Transformation der Delta-Funktion"
}], "Subsubsection"],

Cell[TextData[{
  "Die Diracsche Delta-Funktion besitzt aufgrund von Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  ") eine eindeutige Laplace-Transformierte:"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalL]\_t\%p[\[Delta][t]] = 
      \(\[Integral]\_0\%\[Infinity]\( \[ExponentialE]\^\(\(-p\)\ t\)\) 
            \[Delta][t] \[DifferentialD]t = \(\((1\/2)\).\)\)\)], 
  "NumberedEquation",
  CellTags->"Laplace-Transformation der Delta-Funktion"],

Cell[TextData[{
  "Von diesem Ergebnis weichen viele Ver\[ODoubleDot]ffentlichungen ab. \
Exemplarisch seien lediglich die Quellen angegeben, die bei ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "3.0 in einem Programmkommentar zum Paket ",
  StyleBox["Calculus`DiracDelta ",
    FontSlant->"Italic"],
  "auftauchen: Bei Hoskins ",
  ButtonBox["[Hos1979]",
    ButtonData:>{"Literatur.nb", "[Hos1979]"},
    ButtonStyle->"Hyperlink"],
  " oder Antosik, Mikusinski und Sikorski ",
  ButtonBox["[AMS1973]",
    ButtonData:>{"Literatur.nb", "[AMS1973]"},
    ButtonStyle->"Hyperlink"],
  " ergibt sich das Ergebnis Eins."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Konsequenzen f\[UDoubleDot]r die Computeralgebra"
}], "Subsubsection"],

Cell["\<\
Ein Mathematiker, der mit Bleistift und Papier rechnet, ist in der \
Lage, einen situativen Kontext der Delta-Funktion konsistent durchzuhalten. \
Ein Computeralgebrasystem dagegen mu\[SZ] bei derartigen Spezialit\
\[ADoubleDot]ten zu Rechenfehlern f\[UDoubleDot]hren. Aus diesem Grunde sind \
die Anforderungen an eine konsistent zu formulierende Mathematik bei \
Verwendung von Computeralgebra prinzipiell h\[ODoubleDot]her als beim \
traditionellen Rechnen mit Bleistift und Papier.\
\>", "Text"],

Cell[TextData[{
  "Aufgrund des situativen Kontextes zur Laplace-Transformation der \
Delta-Funktion existiert derzeit kein ausgereiftes Computeralgebrasystem, bei \
dem die Delta-Funktion konsistent oder widerspruchsfrei implementiert w\
\[ADoubleDot]re. Bei ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " war es immerhin m\[ODoubleDot]glich, im Rahmen dieser Arbeit eine \
konsistente Implementation der Delta-Funktion zu erreichen. Das Resultat hei\
\[SZ]t nun aber nicht ",
  StyleBox["DiracDelta",
    FontSlant->"Italic"],
  ", was den historischen Sachverhalt besser beschreiben w\[UDoubleDot]rde, \
sondern ",
  StyleBox["SymmetricalDelta",
    FontSlant->"Italic"],
  ", da dieser Funktionsname noch nicht vergeben war."
}], "Text"],

Cell[TextData[{
  "In diesem Zusammenhang erweist sich vor allem ein \"offenes\" \
Computeralgebrasystem als brauchbar, da der Nutzer des Programms notfalls die \
notwendigen Korrekturen am System selbst vornehmen mu\[SZ]. Das Programmpaket \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ist \"halboffen\", was bedeutet, da\[SZ] eventuelle \
\[CapitalADoubleDot]nderungen von Funktionen unter einem eigenen Namen zu \
implementieren sind."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Laplace-Faltung mit Delta-Funktion"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Die Laplace-Faltung mit einer Delta-Funktion ergibt nach Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Praktisches Delta-Integral"],
  ") die H\[ADoubleDot]lfte der gefalteten Funktion:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%t \[Delta][\[Tau]] f[t - \[Tau]] 
          \[DifferentialD]\[Tau] = 
      \(\[Integral]\_0\%t \[Delta][t - \[Tau]] f[\[Tau]] 
            \[DifferentialD]\[Tau] = \(\((f[t]\/2)\).\)\)\)], 
  "NumberedEquation",
  CellTags->"Laplace-Faltung mit Delta-Funktion"],

Cell[TextData[{
  "Nun ist es freilich nicht sehr praktisch, diesen Faktor ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " beim Vergleich mit der Literatur st\[ADoubleDot]ndig im Auge zu behalten. \
Vielmehr ist es angemessen, bei Verwendung der Laplace-Transformation die \
Funktion ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Delta][t]\)]],
  " anstelle von ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][t]\)]],
  " mit der Inhomogenit\[ADoubleDot]t der Gleichung zu vertauschen. Die \
Laplace-Transformierte davon ist dann Eins, und als Greensche Funktion \
resultiert diejenige Funktion, deren Laplace-Faltung mit der Steuerfunktion \
die allgemeine L\[ODoubleDot]sung ergibt."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Orts- und zeitabh\[ADoubleDot]ngige Steuerfunktionen"
}], "Subsubsection"],

Cell[TextData[{
  "Bei orts- und zeitabh\[ADoubleDot]ngigen Steuerfunktionen ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, y, z, t]\)]],
  " wird die Unabh\[ADoubleDot]ngigkeit der Koordinaten ausgenutzt, was auf \
folgende allgemeinere Inhomogenit\[ADoubleDot]t zur Ermittlung einer \
Greenschen Funktion f\[UDoubleDot]hrt:"
}], "Text"],

Cell[BoxData[
    \(s[x, y, z, t] \[Rule] 
      2  \[Delta][x] \[Delta][y] \[Delta][z] \(\[Delta][t].\)\)], 
  "NumberedEquation",
  CellTags->"\[CapitalUDoubleDot]bergang zur Greenschen Funktion"],

Cell[TextData[{
  "Bei Gleichungen mit ortsunabh\[ADoubleDot]ngigen analytischen \
Koeffizienten, etwa der fraktionalisierten Diffusionsgleichung (1.26), ist \
die Greensche Funktion im Fundamentalsystem der Propagatoren enthalten. Dies \
folgt aus der Laplace-Transformation einer entsprechenden Beispielgleichung f\
\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] \[Element] \[DoubleStruckCapitalN]\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalL]\_t\%p[
              \[PartialD]\^\[Beta] f[x, t]\/\[PartialD]t\^\[Beta] - 
                  \[PartialD]\^2 f[x, t]\/\[PartialD]x\^2 = 
                2  \[Delta][x] \[Delta][t]]\n\n
            \[DoubleLongLeftRightArrow]\ \ \ \ p\^\[Beta] 
           \[ScriptCapitalL]\_t\%p[f[x, t]] - 
        \[Sum]\+\(n = 0\)\%\(\[Beta] - 1\)\[Delta][x] 
            p\^\(\[Beta] - 1 - n\) - 
        \[PartialD]\^2 \[ScriptCapitalL]\_t\%p[f[x, t]]\/\[PartialD]x\^2 = 
      \(\[Delta][x].\)\)], "NumberedEquation",
  CellTags->"Beispiel zur Greenschen Funktion"],

Cell[TextData[{
  "Die v\[ODoubleDot]llige Identit\[ADoubleDot]t des einen der Propagatoren \
mit der Greenschen Funktion ist damit f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`n = \[Beta] - 1\)]],
  " gezeigt. Schwierigere inhomogene Gleichungen lassen sich also auch \
eventuell \[UDoubleDot]ber die homogene L\[ODoubleDot]sung (hier gibt es mehr \
L\[ODoubleDot]sungsverfahren!) behandeln."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Ortsabh\[ADoubleDot]ngige analytische Koeffizienten"
}], "Subsubsection",
  PageBreakAbove->True],

Cell["\<\
Sind die analytischen Koeffizienten einer Gleichung ortsabh\
\[ADoubleDot]ngig, so ist ein besonderes Vorgehen notwendig, um die \
allgemeine L\[ODoubleDot]sung zu errechnen. Hierzu betrachtet man zun\
\[ADoubleDot]chst einmal das Integral einer Fourier-Faltung:\
\>", "Text"],

Cell[BoxData[
    \(f[x]*g[x] = 
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[x - a] g[a] 
            \[DifferentialD]a = 
        \[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[a] g[x - a] 
            \(\[DifferentialD]a.\)\)\)], "NumberedEquation",
  CellTags->"Fourier-Faltung"],

Cell[TextData[{
  "Wird nun der Propagator aufgebaut, so ist zur Anfangszeit ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] 0\)]],
  " eine normale Delta-Faltung gem\[ADoubleDot]\[SZ] Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Theorem"],
  ") gegeben. Zu sp\[ADoubleDot]teren Zeiten ist allerdings nun keine \
Fourier-Faltung mehr zu rechnen, sondern ein Integral, das die ortsabh\
\[ADoubleDot]ngigen Propagatoren mit der Anfangsverteilung als Gewichtung \
aufsummiert."
}], "Text"],

Cell[TextData[{
  "Ortsabh\[ADoubleDot]ngige Propagatoren erh\[ADoubleDot]lt man freilich \
nur, indem auch entsprechend ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta][x - a] + \[Delta][x + a]\)\/2\)]],
  " anstelle von ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][x]\)]],
  " als symmetrisches Anfangswertproblem angesetzt wird. Dasselbe Vorgehen \
ist auch bei der Bildung der Greenschen Funktion zu beachten. Sowohl die \
Propagatoren als auch die Greensche Funktion h\[ADoubleDot]ngen nun vom \
Integrationsabstand ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " in der Fourier-Faltung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fourier-Faltung"],
  ") ab. Bei asymmetrischen Gleichungen ist auch ein asymmetrisches \
Anfangswertproblem der Form ",
  Cell[BoxData[
      \(\[Delta][x - a]\)]],
  " zur Findung der Propagatoren anzusetzen."
}], "Text"],

Cell["\<\
Diese Zusammenh\[ADoubleDot]nge sind bei der L\[ODoubleDot]sung \
entsprechender Fokker-Planck-Gleichungen (Kapitel 1.2.2.3 und 2.4.1.1 dieser \
Arbeit) von Bedeutung. Sie sollen hier nicht weiter er\[ODoubleDot]rtert \
werden, da sie den Rahmen dieser Arbeit sprengen w\[UDoubleDot]rden.\
\>", 
  "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Fourier-Transformation des Riesz-Operators"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Der Riesz-Operator ist bei Samko et al. (",
  ButtonBox["[SKM1993]",
    ButtonData:>{"Literatur.nb", "[SKM1993]"},
    ButtonStyle->"Hyperlink"],
  ", Gln. (12.1)-(12.4), S. 214) so dargestellt, da\[SZ] alle symmetrischen \
und asymmetrischen Varianten des Riesz-Operators damit zusammengebaut werden \
k\[ODoubleDot]nnen."
}], "Text"],

Cell[TextData[{
  "F\[UDoubleDot]r die Diskussion von Diffusion ohne Schwerpunktverschiebung \
reicht folgende Definition aus, die auch als Fourier-Faltung mit der Potenz \
der Betragsfunktion zu verstehen ist und dadurch auf die \
Mellin-Transformation der Cosinus-Funktion f\[UDoubleDot]hrt (",
  ButtonBox["[Obe1974]",
    ButtonData:>{"Literatur.nb", "[Obe1974]"},
    ButtonStyle->"Hyperlink"],
  ", Formeln I.1.2 und I.5.2, S. 11 und 42; ",
  ButtonBox["[EMOT1953]",
    ButtonData:>{"Literatur.nb", "[EMOT1953]"},
    ButtonStyle->"Hyperlink"],
  ", Gln. 1.2(7) und 1.2(15), S. 3 und 5):"
}], "Text"],

Cell[BoxData[
    \(\[ScriptCapitalF]\_x\%k[\(-\(|x\)\)\(|\^\(\(-\[Mu]\) - 1\)\)] = 
      \(\(-\(\[Integral]\_\(-
                \[Infinity]\)\%\[Infinity]\( 
                  \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\) 
              \(\((\(|x | \))\)\^\(\(-\[Mu]\) - 1\)\) \[DifferentialD]x\)\) = 
        \n\t\t\n\(\( = \(-2\) 
            \[Integral]\_0\%\[Infinity] Cos[\(|k | \ x\)]\ 
                \(x\^\(\(-\[Mu]\) - 1\)\) \[DifferentialD]x\) = 
          \(\(-\[ScriptCapitalM]\_x\%\(-\[Mu]\)[Cos[\(|k | \ x\)]]\) = \n
            \t\t\t\t\t\n
            \(\( = \(-\((\(|k | \))\)\^\[Mu]\) \[CapitalGamma][\(-\[Mu]\)] 
                Cos[\(-\(\(\[Mu]\ \[Pi]\)\/2\)\)]\) = 
              \(-\(\(\(2\^\(-\[Mu]\)\) \(\@\[Pi]\) 
                        \[CapitalGamma][\(-\(\[Mu]\/2\)\)]\)\/\[CapitalGamma][
                        \(\[Mu] + 1\)\/2]\)\) 
                \(\((\(|k | \))\)\^\[Mu].\)\)\)\)\)\)], "NumberedEquation",
  CellTags->"Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"],

Cell[TextData[{
  "Der hier gesuchte Riesz-Operator ist so aufzubauen, da\[SZ] \
f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[Rule] 2\)]],
  " die Fourier-Transformierte der zweiten Ortsableitung resultiert, also ",
  Cell[BoxData[
      \(TraditionalForm\`\(-k\^2\)\)]],
  " als Vorfaktor."
}], "Text"],

Cell[TextData[{
  "Dieses Ziel wird durch folgende Fourier-Faltung erreicht, wobei beim \
Riesz-Operator eine Integrationsordnung ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Mu]\)\)]],
  " steht und ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " hier die fraktionale Differentiationsordnung angeben soll:"
}], "Text"],

Cell[BoxData[
    \(\(-\[ScriptCapitalR]\_x\%\(-\[Mu]\)[f[x]]\) = 
      \(\(-\(\(\(2\^\[Mu]\) 
                  \[CapitalGamma][\(\[Mu] + 1\)\/2]\)\/\(\(\@\[Pi]\) 
                  \[CapitalGamma][\(-\(\[Mu]\/2\)\)]\)\)\) 
          \(\[Integral]\_\(-
                \[Infinity]\)\%\[Infinity]\( f[y]
                    \/\(\( \[VerticalBar] x - y
                      \)\( \[VerticalBar] \^\(\[Mu] + 1\)\)\)\) 
              \[DifferentialD]y\) = \n\t\t\n
        \( = \(\((\[ScriptCapitalF]\^\(-1\))\)\_k\%x[
              \(-\(|k \((\(\(|\^\[Mu]\)\ \[ScriptCapitalF]\))\)\_x\%k[
                    f[\(|k | \)]]\)\)].\)\)\)\)], "NumberedEquation",
  CellTags->"diffusions-relevanter Riesz-Operator"],

Cell[TextData[{
  "Die Formulierung dieses Operators geht auf die Arbeit von V. Seshadri und \
B. J. West ",
  ButtonBox["[SWe1982]",
    ButtonData:>{"Literatur.nb", "[SWe1982]"},
    ButtonStyle->"Hyperlink"],
  " zur\[UDoubleDot]ck. Die Fourier-Transformation des f\[UDoubleDot]r die \
driftfreie Diffusion m\[ODoubleDot]glichen Riesz-Operators ist mit Gleichung \
(",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "diffusions-relevanter Riesz-Operator"],
  ") gegeben."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Mellin-Transformation"
}], "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Differenzengleichungen"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Erzeugung von linearen Differenzengleichungen"
}], "Subsubsection"],

Cell[TextData[{
  "Die Laplace-Transformation einer zeit-fraktionalen Diffusionsgleichung f\
\[UDoubleDot]hrt auch f\[UDoubleDot]r ortsabh\[ADoubleDot]ngige \
Diffusionsparameter \[Dash] etwa potenzabh\[ADoubleDot]ngig in der Notation \
nach Risken (",
  ButtonBox["[Ris1984]",
    ButtonData:>{"Literatur.nb", "[Ris1984]"},
    ButtonStyle->"Hyperlink"],
  ", Kap. 1.2.1, S. 4-5) \[Dash] auf eine gew\[ODoubleDot]hnliche \
Differentialgleichung in der Ortskoordinate, deren inhomogene \
L\[ODoubleDot]sung gefragt ist \[Dash] im Falle des genannten Beispiels auf \
Grundgleichungen der Besselfunktionen."
}], "Text"],

Cell[TextData[{
  "Die Mellin-Transformation einer gew\[ODoubleDot]hnlichen homogenen \
Differentialgleichung f\[UDoubleDot]hrt auf eine entsprechende \
Differenzengleichung (",
  ButtonBox["[Mes1959]",
    ButtonData:>{"Literatur.nb", "[Mes1959]"},
    ButtonStyle->"Hyperlink"],
  ", Kap. X.1, S. 133-134). Ist der Zusammenhang (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Beispiel zur Greenschen Funktion"],
  ") zumindest f\[UDoubleDot]r spezielle Anfangswertprobleme (etwa f\
\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][x - 0]\)]],
  ") gesichert, so gen\[UDoubleDot]gt die L\[ODoubleDot]sung der homogenen \
Differenzengleichung des Mellin-Raums zur L\[ODoubleDot]sung der urspr\
\[UDoubleDot]nglich inhomogenen Differentialgleichung."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "L\[ODoubleDot]sung von linearen Differenzengleichungen"
}], "Subsubsection"],

Cell[TextData[{
  "Es existieren L\[ODoubleDot]sungsverfahren (siehe ",
  ButtonBox["[Mes1959]",
    ButtonData:>{"Literatur.nb", "[Mes1959]"},
    ButtonStyle->"Hyperlink"],
  ") homogener und inhomogener linearer Differenzengleichungen. Manchmal l\
\[ADoubleDot]\[SZ]t sich eine der homogenen L\[ODoubleDot]sungen einer \
Differenzengleichung erraten, besonders wenn die L\[ODoubleDot]sungsfunktion \
der zugrundeliegenden Gleichung als Foxsche H-Funktion gegeben ist. Dann \
besteht n\[ADoubleDot]mlich die Mellin-Transformierte der L\[ODoubleDot]sung \
nur aus summenfreien Br\[UDoubleDot]chen der Eulerschen Gamma-Funktion. N\
\[ADoubleDot]here Angaben hierzu finden sich in der Diplomarbeit des \
Verfassers (",
  ButtonBox["[S",
    ButtonData:>{"Literatur.nb", "[Sued1997]"},
    ButtonStyle->"Hyperlink"],
  ButtonBox["\[UDoubleDot]",
    ButtonData:>{"Literatur.nb", "[Sued1997]"},
    ButtonStyle->"Hyperlink"],
  ButtonBox["d1997]",
    ButtonData:>{"Literatur.nb", "[Sued1997]"},
    ButtonStyle->"Hyperlink"],
  ", Abschnitte 5.1.1 und 6.1, S. 65-66 und 75-79)."
}], "Text"],

Cell[TextData[{
  "Im Mellin-Raum ist es recht einfach, durch Kombinatorik und geschicktes K\
\[UDoubleDot]rzen mit Hilfe des Erg\[ADoubleDot]nzungssatzes (",
  ButtonBox["[EMOT1953]",
    ButtonData:>{"Literatur.nb", "[EMOT1953]"},
    ButtonStyle->"Hyperlink"],
  ", Gln. 1.2(6) und 1.2(7), S. 3) eine gewonnene Hauptl\[ODoubleDot]sung in \
weitere Hauptl\[ODoubleDot]sungen (vgl. ",
  ButtonBox["[Mes1959]",
    ButtonData:>{"Literatur.nb", "[Mes1959]"},
    ButtonStyle->"Hyperlink"],
  ", Anm. auf S. 41) im Sinne des Abtasttheorems (",
  ButtonBox["[Mar1986]",
    ButtonData:>{"Literatur.nb", "[Mar1986]"},
    ButtonStyle->"Hyperlink"],
  ", Kap. 6, S. 127-131) umzurechnen. Diese M\[ODoubleDot]glichkeit wird bei \
Mellin unter der Bezeichnung \"passende Substitution\" (",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", Ende von \[Section]5, S. 314) angesprochen."
}], "Text"],

Cell[TextData[{
  "Es war im Rahmen dieser Arbeit leider nicht m\[ODoubleDot]glich, die \
Leistungsf\[ADoubleDot]higkeit der Differenzengleichungen auszuprobieren. In \
der Diplomarbeit von S. Hoffmann ",
  ButtonBox["[Hoff2000]",
    ButtonData:>{"Literatur.nb", "[Hoff2000]"},
    ButtonStyle->"Hyperlink"],
  " finden sich einige verwirklichte L\[ODoubleDot]sungsverfahren und viele \
interessante Literaturangaben zu diesem Thema."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Foxsche H-Funktionen"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "Die inverse Mellin-Transformation der summenfreien Br\[UDoubleDot]che aus \
Eulerschen Gamma-Funktionen ergibt gem\[ADoubleDot]\[SZ] Dixon/Ferrar  ",
  ButtonBox["[DF1936]",
    ButtonData:>{"Literatur.nb", "[DF1936]"},
    ButtonStyle->"Hyperlink"],
  " eine Funktionenklasse, die heute ",
  ButtonBox["[MS1978]",
    ButtonData:>{"Literatur.nb", "[MS1978]"},
    ButtonStyle->"Hyperlink"],
  " als Foxsche H-Funktion bezeichnet wird, weil C. Fox ",
  ButtonBox["[Fox1961]",
    ButtonData:>{"Literatur.nb", "[Fox1961]"},
    ButtonStyle->"Hyperlink"],
  " von der Arbeit seiner Vorg\[ADoubleDot]nger nichts wu\[SZ]te."
}], "Text"],

Cell[TextData[{
  "Kommen summenbehaftete Br\[UDoubleDot]che aus Eulerschen Gamma-Funktionen \
als L\[ODoubleDot]sung zustande, so ergeben sich Baumannsche \
\[Aleph]-Funktionen ",
  ButtonBox["[SBN1998]",
    ButtonData:>{"Literatur.nb", "[SBN1998]"},
    ButtonStyle->"Hyperlink"],
  ", eine Verallgemeinerung der Saxenaschen I-Funktionen ",
  ButtonBox["[Sax1982]",
    ButtonData:>{"Literatur.nb", "[Sax1982]"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "Die Darstellung der Foxschen H-Funktion als inverse Mellin-Transformation \
ergibt (",
  ButtonBox["[SBN1998]",
    ButtonData:>{"Literatur.nb", "[SBN1998]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (1), S. 401) f\[UDoubleDot]r positive ",
  Cell[BoxData[
      \(TraditionalForm\`A\_j\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`B\_j\)]],
  " mit ",
  Cell[BoxData[
      \(TraditionalForm
      \`{m, n, p, q} \[Element] \[DoubleStruckCapitalN]\_0\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SubsuperscriptBox[
          StyleBox["\[ScriptCapitalH]",
            FontSize->16], \(p, q\), \(m, n\)], "[", 
        RowBox[{"x", "|", GridBox[{
             
               {\({{a\_1, A\_1}, ..., {a\_n, A\_n}} | \), 
                \({{a\_\(n + 1\), A\_\(n + 1\)}, ..., {a\_p, A\_p}}\)},
             
               {\({{b\_1, B\_1}, ..., {b\_m, B\_m}} | \), 
                \({{b\_\(m + 1\), B\_\(m + 1\)}, ..., {b\_q, B\_q}}\)}
              }]}], "]"}], "=", "\n", "\t", "\n", 
      \( = \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \[Integral]\_\(\(-\[ImaginaryI]\)\ \[Infinity]\)\%\(\[ImaginaryI]\ 
              \[Infinity]\)\(\(\((
                    \[Product]\+\(j = 1\)\%m \[CapitalGamma][
                        b\_j + \(B\_j\) z])\) 
                  \((\[Product]\+\(j = 1\)\%n \[CapitalGamma][
                        1 - a\_j - \(A\_j\) z])\)\)\/\(\((
                    \[Product]\+\(j = m + 1\)\%q \[CapitalGamma][
                        1 - b\_j - \(B\_j\) z])\) 
                  \((\[Product]\+\(j = n + 1\)\%p \[CapitalGamma][
                        a\_j + \(A\_j\) z])\)\)\) \(x\^\(-z\)\) 
            \(\[DifferentialD]z.\)\)}]], "NumberedEquation",
  CellTags->"Foxsche H-Funktion"],

Cell[TextData[{
  "Noch kompliziertere Mellin-Barnes-Integrale ergeben sich, wenn die \
Riemannsche oder gar Hurwitzsche Zeta-Funktion oder gleich die noch \
allgemeinere Lerchsche Zeta- oder Phi-Funktion im Mellin-Raum als L\
\[ODoubleDot]sung auftaucht (Beispiele hierf\[UDoubleDot]r: ",
  ButtonBox["[Obe1974]",
    ButtonData:>{"Literatur.nb", "[Obe1974]"},
    ButtonStyle->"Hyperlink"],
  ", Formeln I.3.24-I.3.26 und A.16, S. 28 und 272). Die numerische Reihe \
derartiger Funktionen wird normalerweise \[UDoubleDot]ber den Residuensatz \
unter Ausnutzung der Vorarbeiten von Mellin ",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  " und Barnes ",
  ButtonBox["[Bar1908]",
    ButtonData:>{"Literatur.nb", "[Bar1908]"},
    ButtonStyle->"Hyperlink"],
  " vorgenommen."
}], "Text"],

Cell[TextData[{
  "Der wesentliche Unterschied zwischen einer Potenzreihe und einer \
analytischen Funktion besteht nach Barnes ",
  ButtonBox["[Bar1908]",
    ButtonData:>{"Literatur.nb", "[Bar1908]"},
    ButtonStyle->"Hyperlink"],
  " darin, da\[SZ] eine Funktion m\[ODoubleDot]glichst auf der gesamten \
komplexen Zahlenebene eine analytische Fortsetzung und entsprechende \
analytische Eigenschaften besitzt, w\[ADoubleDot]hrend die Potenzreihe f\
\[UDoubleDot]r die Numerik interessant ist."
}], "Text"],

Cell["\<\
Im Falle der als Beispiel erw\[ADoubleDot]hnten Besselschen \
Differentialgleichung ergibt die Mellin-Transformation eine einfache \
Differenzengleichung, wobei die inverse Mellin-Transformation der insgesamt \
vier Hauptl\[ODoubleDot]sungen nicht nur ein optimiertes Fundamentalsystem \
aus zwei modifizierten Besselfunktionen erster Art ergibt, sondern auch die f\
\[UDoubleDot]r die Propagatoren so wichtige modifizierte Besselfunktion \
zweiter Art. Die vierte Hauptl\[ODoubleDot]sung l\[ADoubleDot]\[SZ]t sich \
nicht der inversen Mellin-Transformation unterziehen.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Momentenberechnung aus der Laplace-Transformierten"
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Motivation"
}], "Subsubsection"],

Cell["\<\
Da es in dieser Arbeit eher um die Diskussion der theoretischen \
Varianz im Vergleich mit Me\[SZ]werten geht, ist es wichtig, die Momente \
einer L\[ODoubleDot]sungsfunktion auch dann noch sicher zu berechnen, wenn \
die L\[ODoubleDot]sungsfunktion selbst schon zu kompliziert ist, also den \
Rahmen der Foxschen H-Funktionen sprengt.\
\>", "Text"],

Cell[TextData[{
  "Da die Momente gem\[ADoubleDot]\[SZ] Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Symmetrische Momente"],
  ") mit der Mellin-Transformation zusammenh\[ADoubleDot]ngen, ist ihre \
Berechnung prinzipiell einfacher als die Berechnung einer fertigen L\
\[ODoubleDot]sungsfunktion. Der tiefere Grund hierf\[UDoubleDot]r ist der \
Faltungssatz der Mellin-Transformation (",
  ButtonBox["[Obe1974]",
    ButtonData:>{"Literatur.nb", "[Obe1974]"},
    ButtonStyle->"Hyperlink"],
  ", Formeln I.1.13-I.1.15, S. 12), der zum Beispiel die \
Mellin-Transformierte einer Fourier-Faltung noch in eine Foxsche H-Funktion \
\[UDoubleDot]berf\[UDoubleDot]hrt."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Berechnung"
}], "Subsubsection"],

Cell["\<\
Da die Laplace-Transformierte der L\[ODoubleDot]sungsfunktion \
bereits die Ortskoordinaten besitzt, k\[ODoubleDot]nnen die Momente der \
Laplace-Transformierten auch direkt berechnet werden. Von dem entsprechenden \
Resultat ist die inverse Laplace-Transformierte in die Zeitkoordinate zu  \
bilden.\
\>", "Text"],

Cell[TextData[{
  "Nach Oberhettinger (",
  ButtonBox["[Obe1974]",
    ButtonData:>{"Literatur.nb", "[Obe1974]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (c'), S. 3) ergibt sich als Mellin-Transformierte einer \
Laplace-Transformation"
}], "Text"],

Cell[BoxData[
    \(\(\[ScriptCapitalM]\_p\%y[\[ScriptCapitalL]\_t\%p[f[x, t]]] = 
      \[CapitalGamma][y] \[ScriptCapitalM]\_t\%\(1 - y\)[f[x, t]], \)\)], 
  "NumberedEquation",
  CellTags->"Mellin-Laplace-Transformation"],

Cell["\<\
was die Berechnung der inversen Laplace-Transformation ebenfalls \
\[UDoubleDot]ber die Mellin-Transformation erm\[ODoubleDot]glicht.\
\>", 
  "Text"],

Cell[TextData[{
  "Ergibt etwa die Momentenberechnung einer Laplace-Transformierten eine \
Foxsche H-Funktion, so resultiert wegen des Ergebnisses (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Mellin-Laplace-Transformation"],
  ") auch das Moment der Verteilung als Foxsche H-Funktion. Die \
Verteilungsfunktion selbst ist dann sehr viel komplizierter."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Momentenberechnung aus der Fourier-Transformierten"
}], "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Direkte Berechnung"
}], "Subsubsection"],

Cell["\<\
Ist nur die Fourier-Transformierte einer Verteilungsfunktion \
bekannt, so gestaltet sich die Momentenberechnung deutlich trickreicher als \
bei der Laplace-Transformierten, da jetzt die Ortskoordinate selbst gar nicht \
bekannt ist.\
\>", "Text"],

Cell[TextData[{
  "Trotzdem kann man allgemein f\[UDoubleDot]r symmetrische \
Fourier-Transformierte (solche sind bei diffusiven Vorg\[ADoubleDot]ngen ohne \
Drift vorrangig zu diskutieren) folgenden Zusammenhang herleiten, und zwar \
\[UDoubleDot]ber die Mellin-Transformation einer inversen \
Fourier-Transformierten mit Hilfe des Fubini-Theorems (",
  ButtonBox["[SKM1993]",
    ButtonData:>{"Literatur.nb", "[SKM1993]"},
    ButtonStyle->"Hyperlink"],
  ", Gl. (1.32), S. 9), das die Vertauschbarkeit von Integralen regelt, wobei \
wieder wie im Zusammenhang (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", 
  "Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"],
  ") die Mellin-Transformierte der Cosinus-Funktion auftaucht:"
}], "Text"],

Cell[BoxData[
    RowBox[{\( < \((\(|x\( | \^m\)\))\)\), ",", 
      RowBox[{
      \(\((\[ScriptCapitalF]\^\(-1\))\)\_k\%x[f[\(|k | \), t]] > \), " ", "=",
         
        RowBox[{
        \(\[Integral]\_\(-
                \[Infinity]\)\%\[Infinity]\(\(|x\(|\^m\)\)\/\(2  \[Pi]\)\) 
              \((\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[\(|k | \), t] 
                    \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\) 
                    \[DifferentialD]k)\) \[DifferentialD]x\), "=", "\n", 
          "\t\t", "\n", 
          RowBox[{"=", 
            RowBox[{
            \(\(4\/\(2  \[Pi]\)\) 
                \(\[Integral]\_0
                    \%\[Infinity]\((
                      \[Integral]\_0\%\[Infinity] Cos[\(|k | \ x\)] \(x\^m\) 
                          \[DifferentialD]x)\) f[k, t] \[DifferentialD]k\)\), 
              "=", "\n", "\t\t\t\t", "\n", 
              RowBox[{"=", 
                RowBox[{
                  FractionBox[
                    RowBox[{\(2\^\(1 + m\)\), " ", 
                      RowBox[{
                        StyleBox["\[CapitalGamma]",
                          FontSlant->"Italic"], "[", \(1\/2 + m\/2\), "]"}], 
                      " ", \(\[ScriptCapitalM]\_k\%\(-m\)[f[k, t]]\)}], 
                    RowBox[{\(\@\[Pi]\), " ", 
                      RowBox[{
                        StyleBox["\[CapitalGamma]",
                          FontSlant->"Italic"], "[", \(-\(m\/2\)\), "]"}]}]], 
                  "."}]}]}]}]}]}]}]], "NumberedEquation",
  CellTags->"Momente aus Fourier-Transformierter"],

Cell[TextData[{
  "Die Mellin-Transformierte der Fourier-Transformierten mu\[SZ] recht g\
\[UDoubleDot]nstig gebaut sein, damit das Ergebnis (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Momente aus Fourier-Transformierter"],
  ") mit ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Rule] 2\)]],
  " die Berechnung der Varianz zul\[ADoubleDot]\[SZ]t."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Momente einer Fourier-Faltung"
}], "Subsubsection"],

Cell["\<\
Die Momente einer Fourier-Faltung ergeben ein wesentlich \
einfacheres Theorem (Anhang A dieser Arbeit), das hier wenigstens Erw\
\[ADoubleDot]hnung finden soll:\
\>", "Text"],

Cell[BoxData[
    RowBox[{\( < \((x\^m)\)\), ",", 
      RowBox[{\(f[x]*g[x] > \), " ", "=", 
        RowBox[{
          RowBox[{\(\[Sum]\+\(k = 0\)\%m\), 
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {"m"},
                  {"k"}
                  }], "\[NegativeThinSpace]", ")"}]}], " ", "<", \(x\^k\)}]}],
       ",", \(f[x] > \  < x\^\(m - k\)\), ",", \(g[x] > .\)}]], 
  "NumberedEquation",
  CellTags->"Momententheorem"],

Cell[TextData[{
  "Der Unterschied zwischen den Gleichungen (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Momente aus Fourier-Transformierter"],
  ") und (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Momententheorem"],
  ") besteht vor allem darin, da\[SZ] einmal die symmetrischen Momente und \
einmal die tats\[ADoubleDot]chlichen Momente berechnet werden."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Zusammenfassung"
}], "Section",
  PageBreakAbove->True],

Cell["\<\
Die f\[UDoubleDot]r das Varianztheorem (1.14) so bedeutsame \
Diracsche Delta-Funktion wurde als funktionentheoretisch konsistente \
analytische Funktion der komplexen Zahlenebene vorgestellt.\
\>", "Text"],

Cell["\<\
Die Verwendung der Delta-Funktion bei Anwendung von Laplace- und \
Fourier-Transformation auf eine fraktionale lineare Gleichung wurde \
besprochen. Es ergeben sich optimierte Fundamentalsysteme aus Propagatoren, \
die eventuell sogar die Greensche Funktion der Inhomogenit\[ADoubleDot]t \
beinhalten.\
\>", "Text"],

Cell[TextData[{
  "Der f\[UDoubleDot]r die Diskussion driftfreier Diffusion verwendbare \
Riesz-Operator nach B. J. West ",
  ButtonBox["[SWe1982]",
    ButtonData:>{"Literatur.nb", "[SWe1982]"},
    ButtonStyle->"Hyperlink"],
  " wurde als elegant eingerichtete Fourier-Faltung vorgestellt."
}], "Text"],

Cell["\<\
Die direkte Mellin-Transformation einer linearen \
Differentialgleichung f\[UDoubleDot]hrt oft auf eine Differenzengleichung, \
deren L\[ODoubleDot]sungsmannigfaltigkeit weit \[UDoubleDot]ber die \
Mellin-Transformierten der Foxschen H-Funktionen hinausf\[UDoubleDot]hren \
kann.\
\>", "Text"],

Cell["\<\
Die Berechnung von Momenten aus der Laplace- oder \
Fourier-Transformierten einer Verteilungsfunktion wurde vorgestellt. Dieses \
Vorgehen erleichtert die analytische Diskussion gewaltig, da die Varianz \
eines L\[ODoubleDot]sungspropagators prinzipiell eine einfachere \
Funktionenklasse darstellt als der L\[ODoubleDot]sungspropagator selbst.\
\>",
   "Text"],

Cell["", "Text",
  PageBreakAbove->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Working",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{752, 505},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->31,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Kapitel 2. Mathematische Methoden"}], "Header"]}, {Cell[ 
        TextData[ {"Kapitel 2. Mathematische Methoden"}], "Header"], 
      Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Remark", "Subsubsection"],
  
  Cell[TextData[{
    "The following commands are removed from some of the following \
definitions. To know them anyway they are listed:\n\t",
    StyleBox[" FontSlant->\"Italic\"", "Input"],
    ", \n\t  ",
    StyleBox["SingleLetterItalics->True", "Input"]
  }], "Text"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->PaperWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->PaperWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {4, 4}},
    TextJustification->1,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Output",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->True,
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    FontSize->11],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Times",
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation1"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["NumberedEquation1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure1"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure1", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable1"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable1", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FormatType->InputForm,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    ZeroWidthTimes->True,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    ShowCellBracket->False,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    FormatType->InputForm,
    ScriptLevel->0,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->15],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->10.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Equation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Equation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Equation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->GrayLevel[0.666667]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Centered Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredTitle"],
    CellMargins->{{12, 12}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredTitle", "Presentation"],
    CellMargins->{{24, 24}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["CenteredTitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["CenteredTitle", "Printout"],
    CellMargins->{{2, 2}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubtitle"],
    CellMargins->{{12, 12}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubtitle", "Presentation"],
    CellMargins->{{24, 24}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["CenteredSubtitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["CenteredSubtitle", "Printout"],
    CellMargins->{{2, 2}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubtitle"],
    CellMargins->{{12, 12}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubtitle", "Presentation"],
    CellMargins->{{24, 24}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSubsubtitle", "Condensed"],
    CellMargins->{{8, 8}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsubtitle", "Printout"],
    CellMargins->{{2, 2}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSection"],
    CellMargins->{{12, 12}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsection"],
    CellMargins->{{12, 12}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["CenteredSubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubsection"],
    CellMargins->{{12, 12}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["CenteredSubsubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["CenteredSubsubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Fourier-Transformation"->{
    Cell[5587, 176, 240, 5, 55, "NumberedEquation",
      CellTags->"Fourier-Transformation"]},
  "Cosinus-Transformation"->{
    Cell[6117, 192, 195, 4, 55, "NumberedEquation",
      CellTags->"Cosinus-Transformation"]},
  "Fourier-Transformation der Eins"->{
    Cell[7264, 230, 502, 10, 59, "NumberedEquation",
      CellTags->"Fourier-Transformation der Eins"]},
  "1.Delta-Axiom"->{
    Cell[9650, 302, 144, 3, 35, "NumberedEquation",
      CellTags->"1.Delta-Axiom"]},
  "2.Delta-Axiom"->{
    Cell[9797, 307, 166, 3, 55, "NumberedEquation",
      CellTags->"2.Delta-Axiom"]},
  "3.Delta-Axiom"->{
    Cell[9966, 312, 111, 2, 35, "NumberedEquation",
      CellTags->"3.Delta-Axiom"]},
  "Praktisches Delta-Integral"->{
    Cell[10987, 344, 232, 4, 57, "NumberedEquation",
      CellTags->"Praktisches Delta-Integral"]},
  "Delta-Theorem"->{
    Cell[11553, 359, 179, 3, 55, "NumberedEquation",
      CellTags->"Delta-Theorem"]},
  "Fourier-Transformation der Delta-Funktion"->{
    Cell[12677, 395, 305, 5, 55, "NumberedEquation",
      CellTags->"Fourier-Transformation der Delta-Funktion"]},
  "Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"->{
    Cell[13438, 414, 398, 6, 56, "NumberedEquation",
      CellTags->"Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"]},
  "Fourier-Mellin-Transformationen"->{
    Cell[15478, 479, 1368, 26, 212, "NumberedEquation",
      CellTags->"Fourier-Mellin-Transformationen"]},
  "Mellin-Transformation der Eins"->{
    Cell[17614, 528, 287, 5, 55, "NumberedEquation",
      CellTags->"Mellin-Transformation der Eins"]},
  "Mellin-Residuum der Delta-Funktion"->{
    Cell[18846, 567, 317, 5, 57, "NumberedEquation",
      CellTags->"Mellin-Residuum der Delta-Funktion"]},
  "Mellin-Transformation der Eins explizit 1.Teil"->{
    Cell[21174, 635, 373, 6, 110, "NumberedEquation",
      CellTags->"Mellin-Transformation der Eins explizit 1.Teil"]},
  "Mellin-Transformation der Eins explizit 2.Teil"->{
    Cell[23213, 689, 255, 4, 56, "NumberedEquation",
      CellTags->"Mellin-Transformation der Eins explizit 2.Teil"]},
  "Momente"->{
    Cell[27972, 831, 244, 5, 55, "NumberedEquation",
      CellTags->"Momente"]},
  "Mellin-Transformation"->{
    Cell[28494, 847, 206, 4, 55, "NumberedEquation",
      CellTags->"Mellin-Transformation"]},
  "Symmetrische Momente"->{
    Cell[29481, 874, 421, 7, 108, "NumberedEquation",
      CellTags->"Symmetrische Momente"]},
  "Delta-Momente"->{
    Cell[30759, 915, 333, 7, 57, "NumberedEquation",
      CellTags->"Delta-Momente"]},
  "Null hoch z"->{
    Cell[31560, 936, 139, 3, 59, "NumberedEquation",
      CellTags->"Null hoch z"]},
  "genaueres Null hoch z"->{
    Cell[33707, 1011, 147, 3, 45, "NumberedEquation",
      CellTags->"genaueres Null hoch z"]},
  "Laplace-Transformation der Delta-Funktion"->{
    Cell[42582, 1306, 277, 5, 56, "NumberedEquation",
      CellTags->"Laplace-Transformation der Delta-Funktion"]},
  "Laplace-Faltung mit Delta-Funktion"->{
    Cell[46017, 1410, 298, 6, 56, "NumberedEquation",
      CellTags->"Laplace-Faltung mit Delta-Funktion"]},
  "\[CapitalUDoubleDot]bergang zur Greenschen Funktion"->{
    Cell[47639, 1459, 198, 4, 35, "NumberedEquation",
      CellTags->"\[CapitalUDoubleDot]bergang zur Greenschen Funktion"]},
  "Beispiel zur Greenschen Funktion"->{
    Cell[48285, 1476, 592, 11, 153, "NumberedEquation",
      CellTags->"Beispiel zur Greenschen Funktion"]},
  "Fourier-Faltung"->{
    Cell[49875, 1521, 289, 6, 55, "NumberedEquation",
      CellTags->"Fourier-Faltung"]},
  "Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"->{
    Cell[53167, 1616, 1012, 17, 234, "NumberedEquation",
      CellTags->"Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"]},
  "diffusions-relevanter Riesz-Operator"->{
    Cell[54848, 1657, 709, 13, 139, "NumberedEquation",
      CellTags->"diffusions-relevanter Riesz-Operator"]},
  "Foxsche H-Funktion"->{
    Cell[62749, 1898, 1271, 26, 157, "NumberedEquation",
      CellTags->"Foxsche H-Funktion"]},
  "Mellin-Laplace-Transformation"->{
    Cell[68308, 2053, 224, 4, 42, "NumberedEquation",
      CellTags->"Mellin-Laplace-Transformation"]},
  "Momente aus Fourier-Transformierter"->{
    Cell[70586, 2127, 1572, 33, 241, "NumberedEquation",
      CellTags->"Momente aus Fourier-Transformierter"]},
  "Momententheorem"->{
    Cell[72974, 2194, 460, 11, 69, "NumberedEquation",
      CellTags->"Momententheorem"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Fourier-Transformation", 115401, 3712},
  {"Cosinus-Transformation", 115527, 3715},
  {"Fourier-Transformation der Eins", 115662, 3718},
  {"1.Delta-Axiom", 115789, 3721},
  {"2.Delta-Axiom", 115897, 3724},
  {"3.Delta-Axiom", 116005, 3727},
  {"Praktisches Delta-Integral", 116126, 3730},
  {"Delta-Theorem", 116248, 3733},
  {"Fourier-Transformation der Delta-Funktion", 116385, 3736},
  {"Fourier-Transformation der Eins vollst\[ADoubleDot]ndig", 116564, 3739},
  {"Fourier-Mellin-Transformationen", 116733, 3742},
  {"Mellin-Transformation der Eins", 116880, 3745},
  {"Mellin-Residuum der Delta-Funktion", 117027, 3748},
  {"Mellin-Transformation der Eins explizit 1.Teil", 117190, 3751},
  {"Mellin-Transformation der Eins explizit 2.Teil", 117366, 3754},
  {"Momente", 117502, 3757},
  {"Mellin-Transformation", 117613, 3760},
  {"Symmetrische Momente", 117737, 3763},
  {"Delta-Momente", 117854, 3766},
  {"Null hoch z", 117961, 3769},
  {"genaueres Null hoch z", 118076, 3772},
  {"Laplace-Transformation der Delta-Funktion", 118222, 3775},
  {"Laplace-Faltung mit Delta-Funktion", 118381, 3778},
  {"\[CapitalUDoubleDot]bergang zur Greenschen Funktion", 118550, 3781},
  {"Beispiel zur Greenschen Funktion", 118717, 3784},
  {"Fourier-Faltung", 118850, 3787},
  {"Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator", 119004, 3790},
  {"diffusions-relevanter Riesz-Operator", 119182, 3793},
  {"Foxsche H-Funktion", 119322, 3796},
  {"Mellin-Laplace-Transformation", 119456, 3799},
  {"Momente aus Fourier-Transformierter", 119604, 3802},
  {"Momententheorem", 119741, 3805}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 49, 0, 79, "Subtitle"],

Cell[CellGroupData[{
Cell[1783, 53, 97, 1, 153, "Title",
  CounterAssignments->{{"Title", 1}}],

Cell[CellGroupData[{
Cell[1905, 58, 142, 5, 75, "Section"],
Cell[2050, 65, 479, 11, 113, "Text"],
Cell[2532, 78, 495, 9, 136, "Text"],
Cell[3030, 89, 510, 9, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3577, 103, 120, 5, 75, "Section"],

Cell[CellGroupData[{
Cell[3722, 112, 161, 7, 67, "Subsection"],
Cell[3886, 121, 224, 4, 90, "Text"],
Cell[4113, 127, 335, 6, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4485, 138, 249, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[4759, 150, 291, 9, 60, "Subsubsection"],
Cell[5053, 161, 531, 13, 136, "Text"],
Cell[5587, 176, 240, 5, 55, "NumberedEquation",
  CellTags->"Fourier-Transformation"],
Cell[5830, 183, 284, 7, 67, "Text"],
Cell[6117, 192, 195, 4, 55, "NumberedEquation",
  CellTags->"Cosinus-Transformation"],
Cell[6315, 198, 133, 2, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6485, 205, 282, 9, 60, "Subsubsection"],
Cell[6770, 216, 491, 12, 67, "Text"],
Cell[7264, 230, 502, 10, 59, "NumberedEquation",
  CellTags->"Fourier-Transformation der Eins"],
Cell[7769, 242, 558, 13, 113, "Text"],
Cell[8330, 257, 381, 10, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8748, 272, 315, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[9066, 284, 581, 16, 113, "Text"],
Cell[9650, 302, 144, 3, 35, "NumberedEquation",
  CellTags->"1.Delta-Axiom"],
Cell[9797, 307, 166, 3, 55, "NumberedEquation",
  CellTags->"2.Delta-Axiom"],
Cell[9966, 312, 111, 2, 35, "NumberedEquation",
  CellTags->"3.Delta-Axiom"],
Cell[10080, 316, 347, 9, 67, "Text"],
Cell[10430, 327, 554, 15, 113, "Text"],
Cell[10987, 344, 232, 4, 57, "NumberedEquation",
  CellTags->"Praktisches Delta-Integral"],
Cell[11222, 350, 328, 7, 90, "Text"],
Cell[11553, 359, 179, 3, 55, "NumberedEquation",
  CellTags->"Delta-Theorem"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11769, 367, 223, 9, 60, "Subsubsection"],
Cell[11995, 378, 679, 15, 136, "Text"],
Cell[12677, 395, 305, 5, 55, "NumberedEquation",
  CellTags->"Fourier-Transformation der Delta-Funktion"],
Cell[12985, 402, 450, 10, 113, "Text",
  PageBreakAbove->True],
Cell[13438, 414, 398, 6, 56, "NumberedEquation",
  CellTags->"Fourier-Transformation der Eins vollst\[ADoubleDot]ndig"],
Cell[13839, 422, 434, 11, 90, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14322, 439, 224, 7, 67, "Subsection"],

Cell[CellGroupData[{
Cell[14571, 450, 290, 9, 60, "Subsubsection"],
Cell[14864, 461, 611, 16, 113, "Text"],
Cell[15478, 479, 1368, 26, 212, "NumberedEquation",
  CellTags->"Fourier-Mellin-Transformationen"],
Cell[16849, 507, 762, 19, 113, "Text"],
Cell[17614, 528, 287, 5, 55, "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17938, 538, 309, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[18250, 550, 593, 15, 67, "Text"],
Cell[18846, 567, 317, 5, 57, "NumberedEquation",
  CellTags->"Mellin-Residuum der Delta-Funktion"],
Cell[19166, 574, 566, 13, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19769, 592, 298, 9, 60, "Subsubsection"],
Cell[20070, 603, 575, 14, 113, "Text"],
Cell[20648, 619, 523, 14, 90, "Text"],
Cell[21174, 635, 373, 6, 110, "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins explizit 1.Teil"],
Cell[21550, 643, 1321, 34, 205, "Text"],
Cell[22874, 679, 336, 8, 90, "Text"],
Cell[23213, 689, 255, 4, 56, "NumberedEquation",
  CellTags->"Mellin-Transformation der Eins explizit 2.Teil"],
Cell[23471, 695, 649, 13, 136, "Text",
  PageBreakAbove->True],
Cell[24123, 710, 369, 5, 113, "Text"],
Cell[24495, 717, 610, 13, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25142, 735, 287, 9, 60, "Subsubsection"],
Cell[25432, 746, 267, 7, 67, "Text"],
Cell[25702, 755, 218, 4, 67, "Text"],
Cell[25923, 761, 584, 16, 90, "Text"],
Cell[26510, 779, 390, 9, 90, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26949, 794, 244, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[27218, 806, 307, 9, 60, "Subsubsection"],
Cell[27528, 817, 441, 12, 67, "Text"],
Cell[27972, 831, 244, 5, 55, "NumberedEquation",
  CellTags->"Momente"],
Cell[28219, 838, 272, 7, 67, "Text"],
Cell[28494, 847, 206, 4, 55, "NumberedEquation",
  CellTags->"Mellin-Transformation"],
Cell[28703, 853, 775, 19, 136, "Text"],
Cell[29481, 874, 421, 7, 108, "NumberedEquation",
  CellTags->"Symmetrische Momente"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29939, 886, 279, 9, 60, "Subsubsection"],
Cell[30221, 897, 535, 16, 67, "Text"],
Cell[30759, 915, 333, 7, 57, "NumberedEquation",
  CellTags->"Delta-Momente"],
Cell[31095, 924, 462, 10, 67, "Text"],
Cell[31560, 936, 139, 3, 59, "NumberedEquation",
  CellTags->"Null hoch z"],
Cell[31702, 941, 355, 11, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32094, 957, 258, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[32355, 969, 393, 9, 113, "Text"],
Cell[32751, 980, 953, 29, 136, "Text"],
Cell[33707, 1011, 147, 3, 45, "NumberedEquation",
  CellTags->"genaueres Null hoch z"],
Cell[33857, 1016, 476, 12, 90, "Text"],
Cell[34336, 1030, 710, 22, 113, "Text"],
Cell[35049, 1054, 777, 21, 138, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[35887, 1082, 151, 6, 75, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[36063, 1092, 164, 7, 67, "Subsection"],

Cell[CellGroupData[{
Cell[36252, 1103, 185, 9, 60, "Subsubsection"],
Cell[36440, 1114, 525, 12, 136, "Text"],
Cell[36968, 1128, 752, 16, 182, "Text"],
Cell[37723, 1146, 632, 12, 182, "Text"],
Cell[38358, 1160, 212, 4, 90, "Text"],
Cell[38573, 1166, 370, 10, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38980, 1181, 213, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[39196, 1193, 310, 7, 90, "Text"],
Cell[39509, 1202, 539, 12, 136, "Text"],
Cell[40051, 1216, 555, 12, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40643, 1233, 197, 9, 60, "Subsubsection"],
Cell[40843, 1244, 437, 9, 113, "Text"],
Cell[41283, 1255, 338, 7, 90, "Text"],
Cell[41624, 1264, 265, 5, 90, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41938, 1275, 167, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[42130, 1287, 212, 9, 60, "Subsubsection"],
Cell[42345, 1298, 234, 6, 67, "Text"],
Cell[42582, 1306, 277, 5, 56, "NumberedEquation",
  CellTags->"Laplace-Transformation der Delta-Funktion"],
Cell[42862, 1313, 642, 17, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43541, 1335, 219, 9, 60, "Subsubsection"],
Cell[43763, 1346, 509, 8, 159, "Text"],
Cell[44275, 1356, 753, 17, 182, "Text"],
Cell[45031, 1375, 465, 10, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45533, 1390, 229, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[45765, 1402, 249, 6, 67, "Text"],
Cell[46017, 1410, 298, 6, 56, "NumberedEquation",
  CellTags->"Laplace-Faltung mit Delta-Funktion"],
Cell[46318, 1418, 715, 16, 167, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47070, 1439, 223, 9, 60, "Subsubsection"],
Cell[47296, 1450, 340, 7, 90, "Text"],
Cell[47639, 1459, 198, 4, 35, "NumberedEquation",
  CellTags->"\[CapitalUDoubleDot]bergang zur Greenschen Funktion"],
Cell[47840, 1465, 442, 9, 113, "Text"],
Cell[48285, 1476, 592, 11, 153, "NumberedEquation",
  CellTags->"Beispiel zur Greenschen Funktion"],
Cell[48880, 1489, 420, 8, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49337, 1502, 246, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[49586, 1514, 286, 5, 90, "Text"],
Cell[49875, 1521, 289, 6, 55, "NumberedEquation",
  CellTags->"Fourier-Faltung"],
Cell[50167, 1529, 531, 12, 136, "Text"],
Cell[50701, 1543, 903, 23, 200, "Text"],
Cell[51607, 1568, 315, 6, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51959, 1579, 237, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[52199, 1591, 355, 8, 90, "Text"],
Cell[52557, 1601, 607, 13, 136, "Text"],
Cell[53167, 1616, 1012, 17, 234, "NumberedEquation",
  CellTags->"Hinf\[UDoubleDot]hrung zum symmetrischen Riesz-Operator"],
Cell[54182, 1635, 326, 9, 67, "Text"],
Cell[54511, 1646, 334, 9, 90, "Text"],
Cell[54848, 1657, 709, 13, 139, "NumberedEquation",
  CellTags->"diffusions-relevanter Riesz-Operator"],
Cell[55560, 1672, 502, 13, 90, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[56123, 1692, 137, 6, 75, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[56285, 1702, 152, 7, 67, "Subsection"],

Cell[CellGroupData[{
Cell[56462, 1713, 222, 10, 60, "Subsubsection"],
Cell[56687, 1725, 617, 12, 136, "Text"],
Cell[57307, 1739, 800, 18, 159, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58144, 1762, 231, 10, 60, "Subsubsection"],
Cell[58378, 1774, 1088, 23, 205, "Text"],
Cell[59469, 1799, 947, 21, 159, "Text"],
Cell[60419, 1822, 447, 9, 113, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60903, 1836, 215, 10, 60, "Subsubsection",
  PageBreakAbove->True],
Cell[61121, 1848, 651, 15, 113, "Text"],
Cell[61775, 1865, 464, 12, 90, "Text"],
Cell[62242, 1879, 504, 17, 68, "Text"],
Cell[62749, 1898, 1271, 26, 157, "NumberedEquation",
  CellTags->"Foxsche H-Funktion"],
Cell[64023, 1926, 846, 19, 182, "Text"],
Cell[64872, 1947, 509, 10, 136, "Text"],
Cell[65384, 1959, 594, 9, 182, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[66027, 1974, 204, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[66256, 1986, 181, 9, 60, "Subsubsection"],
Cell[66440, 1997, 359, 6, 113, "Text"],
Cell[66802, 2005, 708, 15, 159, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67547, 2025, 181, 9, 60, "Subsubsection"],
Cell[67731, 2036, 324, 6, 113, "Text"],
Cell[68058, 2044, 247, 7, 67, "Text"],
Cell[68308, 2053, 224, 4, 42, "NumberedEquation",
  CellTags->"Mellin-Laplace-Transformation"],
Cell[68535, 2059, 160, 4, 67, "Text"],
Cell[68698, 2065, 387, 8, 113, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[69134, 2079, 204, 8, 67, "Subsection",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[69363, 2091, 189, 9, 60, "Subsubsection"],
Cell[69555, 2102, 257, 5, 90, "Text"],
Cell[69815, 2109, 768, 16, 159, "Text"],
Cell[70586, 2127, 1572, 33, 241, "NumberedEquation",
  CellTags->"Momente aus Fourier-Transformierter"],
Cell[72161, 2162, 385, 10, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72583, 2177, 200, 9, 60, "Subsubsection"],
Cell[72786, 2188, 185, 4, 67, "Text"],
Cell[72974, 2194, 460, 11, 69, "NumberedEquation",
  CellTags->"Momententheorem"],
Cell[73437, 2207, 415, 11, 90, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[73913, 2225, 131, 6, 75, "Section",
  PageBreakAbove->True],
Cell[74047, 2233, 216, 4, 90, "Text"],
Cell[74266, 2239, 325, 6, 113, "Text"],
Cell[74594, 2247, 304, 7, 67, "Text"],
Cell[74901, 2256, 303, 6, 90, "Text"],
Cell[75207, 2264, 371, 7, 113, "Text"],
Cell[75581, 2273, 40, 1, 44, "Text",
  PageBreakAbove->True]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

